/*
 * taskview-application-proxy.h
 *
 * TaskviewApplicationProxy
 *
 * Copyright © 2010 Salomon Sickert
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 3 of the licence or (at
 * your option) any later version.
 *
 * See the included COPYING file for more information.
 *
 * Authors:
 *    Salomon Sickert <sickert@in.tum.de>
 */

#ifndef __TASKVIEW_APPLICATION_PROXY_H__
#define __TASKVIEW_APPLICATION_PROXY_H__

#include <glib-object.h>
#include <gio/gio.h>
#include "taskview-generic-proxy.h"
#include "taskview-io-proxy.h"

G_BEGIN_DECLS

#define TASKVIEW_TYPE_APPLICATION_PROXY	(taskview_application_proxy_get_type ())
#define TASKVIEW_APPLICATION_PROXY(obj)	(G_TYPE_CHECK_INSTANCE_CAST ((obj), TASKVIEW_TYPE_APPLICATION_PROXY, TaskviewApplicationProxy))
#define TASKVIEW_APPLICATION_PROXY_CLASS(obj)	(G_TYPE_CHECK_CLASS_CAST ((obj), TASKVIEW_TYPE_APPLICATION_PROXY, TaskviewApplicationProxyClass))
#define TASKVIEW_IS_APPLICATION_PROXY(obj)	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), TASKVIEW_TYPE_APPLICATION_PROXY))
#define TASKVIEW_IS_APPLICATION_PROXY_CLASS(obj)	(G_TYPE_CHECK_CLASS_TYPE ((obj), TASKVIEW_TYPE_APPLICATION_PROXY))
#define TASKVIEW_APPLICATION_PROXY_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), TASKVIEW_TYPE_APPLICATION_PROXY, TaskviewApplicationProxyClass))

typedef struct _TaskviewApplicationProxy TaskviewApplicationProxy;
typedef struct _TaskviewApplicationProxyClass TaskviewApplicationProxyClass;
typedef struct _TaskviewApplicationProxyPrivate TaskviewApplicationProxyPrivate;

struct _TaskviewApplicationProxy
{
  GObject parent;
  TaskviewApplicationProxyPrivate *priv;
};

struct _TaskviewApplicationProxyClass
{
  GObjectClass parent_class;
};

GType taskview_application_proxy_get_type (void);

const GHashTable * taskview_application_proxy_get_views (TaskviewApplicationProxy *proxy);
TaskviewIOProxy *  taskview_application_proxy_get_io_proxy (TaskviewApplicationProxy *proxy, const gchar *object_path);
TaskviewGenericProxy * taskview_application_proxy_get_generic_proxy (TaskviewApplicationProxy *proxy, const gchar *object_path);

/* C Wrapper */

gchar * taskview_application_proxy_get_application_name (TaskviewApplicationProxy *self);

G_END_DECLS

#endif
